@@ -106,6 +106,8 @@ class IpaCloud(object):
         prefix_name=None,
         retry_count=None,
         root_disk_size=None,
+        beta=None,
+        exclude=None,
         custom_args=None
     ):
         """Initialize base cloud framework class."""
@@ -174,6 +176,8 @@ class IpaCloud(object):
         self.prefix_name = self.ipa_config['prefix_name']
         self.retry_count = int(self.ipa_config['retry_count'])
         self.root_disk_size = int(self.ipa_config['root_disk_size'])
+        self.beta = self.ipa_config['beta']
+        self.exclude = exclude or []
 
         if self.enable_secure_boot and not self.enable_uefi:
             self.enable_uefi = True
@@ -207,7 +211,11 @@ class IpaCloud(object):
             )
         }
 
-        self._parse_test_files(test_dirs, self.no_default_test_dirs)
+        self._parse_test_files(
+            test_dirs,
+            self.no_default_test_dirs,
+            self.exclude
+        )
         self.post_init()
 
     def post_init(self):
@@ -291,7 +299,7 @@ class IpaCloud(object):
         for key, value in results['summary'].items():
             self.results['summary'][key] += value
 
-    def _parse_test_files(self, test_dirs, no_default_test_dirs):
+    def _parse_test_files(self, test_dirs, no_default_test_dirs, exclude):
         """
         Collect all test dirs and expand test files.
 
@@ -324,7 +332,8 @@ class IpaCloud(object):
 
         self.test_files = ipa_utils.expand_test_files(
             self.test_dirs,
-            self.test_files
+            self.test_files,
+            exclude
         )
 
     def _process_test_results(self, duration, test_name, success=0):
@@ -354,6 +363,9 @@ class IpaCloud(object):
         if self.early_exit:
             options.append('-x')
 
+        if self.beta:
+            options.append('-m "not skipinbeta"')
+
         args = '-v -s {} --json-report-file=none ' \
                '--ssh-config={} --hosts={} {}'.format(
                    ' '.join(options),
@@ -384,7 +396,7 @@ class IpaCloud(object):
                 result = 3  # See below for pytest error codes
                 self.logger.exception(str(error))
 
-            if result != 0:
+            if result not in (0, 5):
                 num_retries += 1
             else:
                 break
@@ -397,6 +409,11 @@ class IpaCloud(object):
         else:
             self._merge_results(plugin.report)
 
+        if result == 5:
+            # pytest exit code 5 no tests collected.
+            # Expected case when using beta flag.
+            result = 0
+
         return result
 
     def _save_results(self):
