@@ -92,7 +92,10 @@ def test_image(
     root_disk_size=None,
     gallery_name=None,
     gallery_resource_group=None,
-    image_version=None
+    image_version=None,
+    architecture=None,
+    beta=None,
+    exclude=None
 ):
     """Creates a cloud framework instance and initiates testing."""
     kwargs = {
@@ -123,7 +126,9 @@ def test_image(
         'log_callback': log_callback,
         'prefix_name': prefix_name,
         'retry_count': retry_count,
-        'root_disk_size': root_disk_size
+        'root_disk_size': root_disk_size,
+        'beta': beta,
+        'exclude': exclude
     }
 
     cloud_name = cloud_name.lower()
@@ -153,7 +158,8 @@ def test_image(
             'service_account_file': service_account_file,
             'image_project': image_project,
             'sev_capable': sev_capable,
-            'use_gvnic': use_gvnic
+            'use_gvnic': use_gvnic,
+            'architecture': architecture
         }
         cloud = GCECloud(**kwargs)
     elif cloud_name == 'ssh':
