@@ -119,6 +119,10 @@ class GCECloud(IpaCloud):
         self.image_project = self.custom_args.get('image_project')
         self.sev_capable = self.custom_args.get('sev_capable')
         self.use_gvnic = self.custom_args.get('use_gvnic')
+        self.architecture = self.custom_args.get(
+            'architecture',
+            'x86_64'
+        ).upper()
 
         self.credentials = self._get_credentials()
         self.compute_driver = self._get_driver()
@@ -336,6 +340,7 @@ class GCECloud(IpaCloud):
         source_image,
         ssh_key,
         root_disk_size,
+        architecture,
         auto_delete=True,
         boot_disk=True,
         disk_type='PERSISTENT',
@@ -368,7 +373,8 @@ class GCECloud(IpaCloud):
                 'initializeParams': {
                     'diskName': instance_name,
                     'sourceImage': source_image,
-                    'diskSizeGb': root_disk_size
+                    'diskSizeGb': root_disk_size,
+                    'architecture': architecture
                 }
             }],
             'networkInterfaces': network_interfaces,
@@ -418,7 +424,8 @@ class GCECloud(IpaCloud):
             'network_interfaces': network_interfaces,
             'sev_capable': self.sev_capable,
             'use_gvnic': self.use_gvnic,
-            'root_disk_size': self.root_disk_size
+            'root_disk_size': self.root_disk_size,
+            'architecture': self.architecture
         }
 
         if self.enable_uefi:
