@@ -31,7 +31,8 @@ import click
 from img_proof.ipa_constants import (
     IPA_HISTORY_FILE,
     SUPPORTED_DISTROS,
-    SUPPORTED_CLOUDS
+    SUPPORTED_CLOUDS,
+    SUPPORTED_ARCHITECTURES
 )
 from img_proof import ipa_utils
 from img_proof.ipa_constants import TEST_PATHS
@@ -354,6 +355,25 @@ def main(context, no_color):
     help='The version of the gallery image definition to use '
          'for testing in semantic versioning format: "2022.02.02".'
 )
+@click.option(
+    '--architecture',
+    default='x86_64',
+    type=click.Choice(SUPPORTED_ARCHITECTURES),
+    help='The architecture of the compute image being tested. '
+         'Default: x86_64.',
+)
+@click.option(
+    '--beta',
+    is_flag=True,
+    help='Running tests on a product in beta. Skip any tests '
+         'that are expected to fail.'
+)
+@click.option(
+    '--exclude',
+    help='Optional tests to exclude. Can be used multiple times. '
+         'Example: "img-proof test gce --exclude test_1 --exclude test_2"',
+    multiple=True
+)
 @click.argument('tests', nargs=-1)
 @click.pass_context
 def test(context,
@@ -410,6 +430,9 @@ def test(context,
          gallery_name,
          gallery_resource_group,
          image_version,
+         architecture,
+         beta,
+         exclude,
          tests):
     """Test image in the given framework using the supplied test files."""
     no_color = context.obj['no_color']
@@ -471,7 +494,10 @@ def test(context,
             root_disk_size,
             gallery_name,
             gallery_resource_group,
-            image_version
+            image_version,
+            architecture,
+            beta,
+            exclude
         )
         echo_results(results, no_color)
         sys.exit(status)
