@@ -153,6 +153,14 @@ def is_sles_sapcal(host):
     return f
 
 
+@pytest.fixture()
+def is_sle_micro(host, get_release_value):
+    def f():
+        name = get_release_value('PRETTY_NAME')
+        return 'micro' in name.lower()
+    return f
+
+
 @pytest.fixture()
 def get_release_value(host):
     def f(key):
@@ -230,3 +238,17 @@ def confirm_license_content(host):
 
         return False
     return f
+
+
+@pytest.fixture()
+def is_byos(host):
+    def f():
+        result = host.run('rpm -q cloud-regionsrv-client')
+        service = host.service('guestregister.service')
+        is_client_installed = result.rc == 0
+
+        if is_client_installed and service.is_enabled:
+            return False
+        else:
+            return True
+    return f
